![pypi](https://img.shields.io/pypi/v/umlcharter.svg)
![versions](https://img.shields.io/pypi/pyversions/umlcharter.svg)
![PyPI - Downloads](https://img.shields.io/pypi/dm/umlcharter)

# umlcharter
Python package for quick diagrams creation without a need to learn a new DSL.

The goal of this package is to provide a tool for convenient and quick creation of the diagrams as a code
in the popular DSLs (PlantUML, Mermaid, D2, etc) using simple python constructions.

This package focuses on not to provide the full coverage for the all the things these DSLs are supporting, but rather on
the simplicity, speed and ease of diagrams creation.

For the examples of how this package can be used and the list of exactly supported DSLs, 
please check the documentation:
- [Sequence Diagrams](https://github.com/mikalaiyurkin/umlcharter/blob/master/docs/sequence_diagram/README.md)
- [State & Activity Diagrams (Flowcharts)](https://github.com/mikalaiyurkin/umlcharter/blob/master/docs/graph_diagram/README.md)
